====================================
Package Helper Test 2022 01 18 17h12
====================================


.. image:: https://img.shields.io/pypi/v/package_helper_test_2022_01_18_17h12.svg
        :target: https://pypi.python.org/pypi/package_helper_test_2022_01_18_17h12
        :alt: PyPI Status

.. image:: https://github.com/francois-durand/package_helper_test_2022_01_18_17h12/workflows/build/badge.svg?branch=main
        :target: https://github.com/francois-durand/package_helper_test_2022_01_18_17h12/actions?query=workflow%3Abuild
        :alt: Build Status

.. image:: https://github.com/francois-durand/package_helper_test_2022_01_18_17h12/workflows/docs/badge.svg?branch=main
        :target: https://github.com/francois-durand/package_helper_test_2022_01_18_17h12/actions?query=workflow%3Adocs
        :alt: Documentation Status


.. image:: https://codecov.io/gh/francois-durand/package_helper_test_2022_01_18_17h12/branch/main/graphs/badge.svg
        :target: https://codecov.io/gh/francois-durand/package_helper_test_2022_01_18_17h12/tree/main
        :alt: Code Coverage



This is a test of Package Helper 2. So nice.


* Free software: GNU General Public License v3
* Documentation: https://francois-durand.github.io/package_helper_test_2022_01_18_17h12/.


--------
Features
--------

* TODO

-------
Credits
-------

This package was created with Cookiecutter_ and the `francois-durand/package_helper_2`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`francois-durand/package_helper_2`: https://github.com/francois-durand/package_helper_2
